@@ -21,7 +21,6 @@
  *   Copyright (C) 2004 Nadeem Hasan <nhasan@kde.org>
  *   Copyright (C) 2004 Stefan Kombrink <katakombi@web.de>
  */
-#include <sys/shm.h>
 #include <string.h>
 #include "gsynaptics.h"
 
@@ -129,25 +128,9 @@ static void
 g_synaptics_init (GSynaptics *synaptics)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
-	int shmid;
 
 	priv->synclient = FALSE;
 
-	if ((shmid = shmget(SHM_SYNAPTICS, sizeof(SynapticsSHM), 0)) == -1)
-       	{
-		if ((shmid = shmget(SHM_SYNAPTICS, 0, 0)) == -1) 
-			g_warning("Access denied to driver shared memory");
-        	else
-			g_warning("Shared memory segment size mismatch");
-		priv->synshm = NULL;
-	}
-       	else
-	{
-		if ((priv->synshm = (SynapticsSHM*) shmat(shmid, NULL, 0)) == NULL) 
-			g_warning("Error attaching to shared memory segment");
-	}
-
-	if (priv->synshm == NULL)
 	{
 		gchar *find;
 		find = g_find_program_in_path("synclient");
